==> haskell-pcg-random-0.1.4.0-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pcg-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pcg-random
version:              0.1.4.0
visibility:           public
id:                   pcg-random-0.1.4.0-BvJo9fkWGp89DeVRnjte6b
key:                  pcg-random-0.1.4.0-BvJo9fkWGp89DeVRnjte6b
license:              BSD-3-Clause
copyright:            (c) 2014-2015. Christopher Chalmers <c.chalmers@me.com>
maintainer:           c.chalmers@me.com
author:               Christopher Chalmers
homepage:             http://github.com/cchalmers/pcg-random
synopsis:             Haskell bindings to the PCG random number generator.
description:
    PCG is a family of simple fast space-efficient statistically good
    algorithms for random number generation. Unlike many general-purpose
    RNGs, they are also hard to predict.

    This library implements bindings to the standard C implementation.
    This includes the standard, unique, fast and single variants in the
    pcg family. There is a pure implementation that can be used as a
    generator with the random package as well as a faster primitive api
    that includes functions for generating common types.

    The generators in this module are suitable for use in parallel but
    make sure threads don'\''t share the same generator or things will go
    horribly wrong.

category:             System
abi:                  99840aeacc855f99364e97027d5b3aac
exposed:              True
exposed-modules:
    System.Random.PCG System.Random.PCG.Class System.Random.PCG.Fast
    System.Random.PCG.Fast.Pure System.Random.PCG.Pure
    System.Random.PCG.Single System.Random.PCG.Unique

import-dirs:          /usr/lib/ghc-9.2.8/site-local/pcg-random-0.1.4.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pcg-random-0.1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pcg-random
hs-libraries:         HSpcg-random-0.1.4.0-BvJo9fkWGp89DeVRnjte6b
include-dirs:         /usr/lib/ghc-9.2.8/site-local/pcg-random-0.1.4.0/include
includes:             pcg_variants.h
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    entropy-0.4.1.10-C5y4ZMubclPFkOssafbGqV
    primitive-0.7.4.0-I9XTAmFqErC1hXdXvvNzkS
    random-1.2.1.2-3aSfWlsu7xc3wK3TRJn2vY

haddock-interfaces:   /usr/share/doc/haskell-pcg-random/html/pcg-random.haddock
haddock-html:         /usr/share/doc/haskell-pcg-random/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pcg-random-0.1.4.0-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pcg-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pcg-random
version:              0.1.4.0
visibility:           public
id:                   pcg-random-0.1.4.0-AKc6Wb2ncdn6uHkBAxWmWM
key:                  pcg-random-0.1.4.0-AKc6Wb2ncdn6uHkBAxWmWM
license:              BSD-3-Clause
copyright:            (c) 2014-2015. Christopher Chalmers <c.chalmers@me.com>
maintainer:           c.chalmers@me.com
author:               Christopher Chalmers
homepage:             http://github.com/cchalmers/pcg-random
synopsis:             Haskell bindings to the PCG random number generator.
description:
    PCG is a family of simple fast space-efficient statistically good
    algorithms for random number generation. Unlike many general-purpose
    RNGs, they are also hard to predict.

    This library implements bindings to the standard C implementation.
    This includes the standard, unique, fast and single variants in the
    pcg family. There is a pure implementation that can be used as a
    generator with the random package as well as a faster primitive api
    that includes functions for generating common types.

    The generators in this module are suitable for use in parallel but
    make sure threads don'\''t share the same generator or things will go
    horribly wrong.

category:             System
abi:                  e00864d5ec293ace04a84534f5574a92
exposed:              True
exposed-modules:
    System.Random.PCG System.Random.PCG.Class System.Random.PCG.Fast
    System.Random.PCG.Fast.Pure System.Random.PCG.Pure
    System.Random.PCG.Single System.Random.PCG.Unique

import-dirs:          /usr/lib/ghc-9.2.8/site-local/pcg-random-0.1.4.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pcg-random-0.1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pcg-random
hs-libraries:         HSpcg-random-0.1.4.0-AKc6Wb2ncdn6uHkBAxWmWM
include-dirs:         /usr/lib/ghc-9.2.8/site-local/pcg-random-0.1.4.0/include
includes:             pcg_variants.h
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    entropy-0.4.1.10-C5y4ZMubclPFkOssafbGqV
    primitive-0.7.4.0-LS5OACsFMkWJjOUaCwrwBF
    random-1.2.1.2-A1nmgsccnvnI4hMd5jmfsN

haddock-interfaces:   /usr/share/doc/haskell-pcg-random/html/pcg-random.haddock
haddock-html:         /usr/share/doc/haskell-pcg-random/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
